@@ -13,12 +13,16 @@ from .errors import (AuthValidationFailed, MissingAuthorizationHeader,
                      WebAuthFailed)
 
 
-def get_auth(request: Request) -> AuthSpec:
+def get_req_auth(request: Request) -> AuthSpec:
     """a shortcut to get the Auth object from a web context"""
 
-    current_app: Sanic = Sanic.get_app(request.app.name)
+    return request.app.ctx.auth
 
-    return current_app.ctx.auth
+
+def get_app_auth(app: Sanic) -> AuthSpec:
+    """a shortcut to get the Auth object from a web context"""
+
+    return app.ctx.auth
 
 
 def protected(scopes: Optional[List[str]] = None, require_all=True):
@@ -35,7 +39,7 @@ def protected(scopes: Optional[List[str]] = None, require_all=True):
     def decorator(f):
         @wraps(f)
         async def decorated_function(request, *args, **kwargs):
-            auth = get_auth(request)
+            auth = get_req_auth(request)
             token = request.token
             if not token:
                 raise MissingAuthorizationHeader()
@@ -59,21 +63,9 @@ def auth_error_handler(request, exception):
     return json({"msg": "Authentication failed"}, status=401)
 
 
-# def sanic_init_auth(app: Sanic, auth: AuthSpec, settings: Settings):
-#     app.ctx.auth = auth
-#     app.config.AUTH_SALT = settings.SECURITY.AUTH_SALT
-#     app.config.AUTH_ALLOW_REFRESH = settings.SECURITY.AUTH_ALLOW_REFRESH
-#     app.config.USERS = UserManager(settings.USER_MODEL)
-#     # app.ctx.authenticate = get_class(settings.AUTH_FUNCTION)
-#
-#     app.error_handler.add(WebAuthFailed, auth_error_handler)
-#     app.error_handler.add(MissingAuthorizationHeader, auth_error_handler)
-
-
 class WebApp(WebAppSpec):
     name = "security"
     package_dir = "services.security"
-    bp_modules = []
 
     def init(self, app: Sanic, settings: Settings):
         store = None
