@@ -17,6 +17,15 @@ SECURITY = types.SecuritySettings(
 
 USER_MODEL = "{{ data.app_name }}.models.UserModel"
 
+DATABASES = {
+    "default": types.Database(
+        name="default",
+        async_url="sqlite+aiosqlite:///db.sqlite",
+        sync_url="sqlite:///db.sqlite",
+        description="Default database",
+    )
+}
+
 APPS = [
     # "services.users.web.WebApp",
     "services.security.web.WebApp",
